@@ -2,7 +2,7 @@ package CPAN::HandleConfig;
 use strict;
 use vars qw(%can %keys $dot_cpan $VERSION);
 
-$VERSION = sprintf "%.2f", substr(q$Rev: 366 $,4)/100;
+$VERSION = sprintf "%.2f", substr(q$Rev: 423 $,4)/100;
 
 %can = (
   'commit' => "Commit changes to disk",
@@ -12,7 +12,7 @@ $VERSION = sprintf "%.2f", substr(q$Rev: 366 $,4)/100;
 
 %keys = map { $_ => undef } qw(
     build_cache build_dir bzip2
-    cache_metadata cpan_home curl
+    cache_metadata commandnumber_in_prompt cpan_home curl
     dontload_hash
     ftp ftp_proxy
     getcwd gpg gzip
@@ -117,7 +117,15 @@ sub prettyprint {
 }
 
 sub commit {
-    my($self,$configpm) = @_;
+    my($self,@args) = @_;
+    my $configpm;
+    if (@args) {
+      if ($args[0] eq "args") {
+        # we have not signed that contract
+      } else {
+        $configpm = $args[0];
+      }
+    }
     unless (defined $configpm){
 	$configpm ||= $INC{"CPAN/MyConfig.pm"};
 	$configpm ||= $INC{"CPAN/Config.pm"};
@@ -164,7 +172,7 @@ EOF
     #$mode = 0444 | ( $mode & 0111 ? 0111 : 0 );
     #chmod $mode, $configpm;
 ###why was that so?    $self->defaults;
-    $CPAN::Frontend->myprint("commit: wrote $configpm\n");
+    $CPAN::Frontend->myprint("commit: wrote '$configpm'\n");
     1;
 }
 
@@ -223,12 +231,12 @@ sub load {
 
     my(@miss);
     use Carp;
-    eval {require CPAN::Config;};       # We eval because of some
-                                        # MakeMaker problems
+    unless ($INC{"CPAN/MyConfig.pm"}) { # this guy has settled his needs already
+      eval {require CPAN::Config;}; # not everybody has one
+    }
     unless ($dot_cpan++){
       unshift @INC, File::Spec->catdir($ENV{HOME},".cpan");
-      eval {require CPAN::MyConfig;};   # where you can override
-                                        # system wide settings
+      eval {require CPAN::MyConfig;}; # override system wide settings
       shift @INC;
     }
     return unless @miss = $self->missing_config_data;
@@ -377,7 +385,7 @@ package ####::###### #hide from indexer
 
 use strict;
 use vars qw($AUTOLOAD $VERSION);
-$VERSION = sprintf "%.2f", substr(q$Rev: 366 $,4)/100;
+$VERSION = sprintf "%.2f", substr(q$Rev: 423 $,4)/100;
 
 # formerly CPAN::HandleConfig was known as CPAN::Config
 sub AUTOLOAD {
